@@ -1,12 +1,14 @@
 import xcffib
 import struct
 import io
-MAJOR_VERSION = 0
-MINOR_VERSION = 0
+MAJOR_VERSION = 1
+MINOR_VERSION = 2
 key = xcffib.ExtensionKey("DPMS")
 _events = {}
 _errors = {}
+from . import xproto
 class GetVersionReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -17,6 +19,7 @@ class GetVersionReply(xcffib.Reply):
 class GetVersionCookie(xcffib.Cookie):
     reply_type = GetVersionReply
 class CapableReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -27,6 +30,7 @@ class CapableReply(xcffib.Reply):
 class CapableCookie(xcffib.Cookie):
     reply_type = CapableReply
 class GetTimeoutsReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -42,6 +46,7 @@ class DPMSMode:
     Suspend = 2
     Off = 3
 class InfoReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -51,6 +56,33 @@ class InfoReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 class InfoCookie(xcffib.Cookie):
     reply_type = InfoReply
+class EventMask:
+    InfoNotify = 1 << 0
+class InfoNotifyEvent(xcffib.Event):
+    xge = True
+    def __init__(self, unpacker):
+        if isinstance(unpacker, xcffib.Protobj):
+            unpacker = xcffib.MemoryUnpacker(unpacker.pack())
+        xcffib.Event.__init__(self, unpacker)
+        base = unpacker.offset
+        self.timestamp, self.power_level, self.state = unpacker.unpack("xx2x2xIHB21x")
+        self.bufsize = unpacker.offset - base
+    def pack(self):
+        buf = io.BytesIO()
+        buf.write(struct.pack("=B", 0))
+        buf.write(struct.pack("=x2x2xIHB21x", self.timestamp, self.power_level, self.state))
+        buf_len = len(buf.getvalue())
+        if buf_len < 32:
+            buf.write(struct.pack("x" * (32 - buf_len)))
+        return buf.getvalue()
+    @classmethod
+    def synthetic(cls, timestamp, power_level, state):
+        self = cls.__new__(cls)
+        self.timestamp = timestamp
+        self.power_level = power_level
+        self.state = state
+        return self
+_events[0] = InfoNotifyEvent
 class dpmsExtension(xcffib.Extension):
     def GetVersion(self, client_major_version, client_minor_version, is_checked=True):
         buf = io.BytesIO()
@@ -84,4 +116,8 @@ class dpmsExtension(xcffib.Extension):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(7, buf, InfoCookie, is_checked=is_checked)
+    def SelectInput(self, event_mask, is_checked=False):
+        buf = io.BytesIO()
+        buf.write(struct.pack("=xx2xI", event_mask))
+        return self.send_request(8, buf, is_checked=is_checked)
 xcffib._add_ext(key, dpmsExtension, _events, _errors)
