@@ -2,7 +2,7 @@ import xcffib
 import struct
 import io
 MAJOR_VERSION = 1
-MINOR_VERSION = 2
+MINOR_VERSION = 3
 key = xcffib.ExtensionKey("Present")
 _events = {}
 _errors = {}
@@ -27,11 +27,13 @@ class Option:
     Copy = 1 << 1
     UST = 1 << 2
     Suboptimal = 1 << 3
+    AsyncMayTear = 1 << 4
 class Capability:
     _None = 0
     Async = 1 << 0
     Fence = 1 << 1
     UST = 1 << 2
+    AsyncMayTear = 1 << 3
 class CompleteKind:
     Pixmap = 0
     NotifyMSC = 1
@@ -41,6 +43,7 @@ class CompleteMode:
     Skip = 2
     SuboptimalCopy = 3
 class Notify(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -60,6 +63,7 @@ class Notify(xcffib.Struct):
         self.serial = serial
         return self
 class QueryVersionReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -70,6 +74,7 @@ class QueryVersionReply(xcffib.Reply):
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 class QueryCapabilitiesReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -80,6 +85,7 @@ class QueryCapabilitiesReply(xcffib.Reply):
 class QueryCapabilitiesCookie(xcffib.Cookie):
     reply_type = QueryCapabilitiesReply
 class GenericEvent(xcffib.Event):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -105,6 +111,7 @@ class GenericEvent(xcffib.Event):
         return self
 _events[0] = GenericEvent
 class ConfigureNotifyEvent(xcffib.Event):
+    xge = True
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -137,6 +144,7 @@ class ConfigureNotifyEvent(xcffib.Event):
         return self
 _events[0] = ConfigureNotifyEvent
 class IdleNotifyEvent(xcffib.Event):
+    xge = True
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
