@@ -1,6 +1,6 @@
 import xcffib
 import struct
-import six
+import io
 MAJOR_VERSION = 1
 MINOR_VERSION = 2
 key = xcffib.ExtensionKey("X-Resource")
@@ -8,6 +8,7 @@ _events = {}
 _errors = {}
 from . import xproto
 class Client(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -16,7 +17,7 @@ class Client(xcffib.Struct):
         self.resource_base, self.resource_mask = unpacker.unpack("II")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=II", self.resource_base, self.resource_mask))
         return buf.getvalue()
     fixed_size = 8
@@ -27,6 +28,7 @@ class Client(xcffib.Struct):
         self.resource_mask = resource_mask
         return self
 class Type(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -35,7 +37,7 @@ class Type(xcffib.Struct):
         self.resource_type, self.count = unpacker.unpack("II")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=II", self.resource_type, self.count))
         return buf.getvalue()
     fixed_size = 8
@@ -49,6 +51,7 @@ class ClientIdMask:
     ClientXID = 1 << 0
     LocalClientPID = 1 << 1
 class ClientIdSpec(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -57,7 +60,7 @@ class ClientIdSpec(xcffib.Struct):
         self.client, self.mask = unpacker.unpack("II")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=II", self.client, self.mask))
         return buf.getvalue()
     fixed_size = 8
@@ -68,6 +71,7 @@ class ClientIdSpec(xcffib.Struct):
         self.mask = mask
         return self
 class ClientIdValue(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -79,9 +83,9 @@ class ClientIdValue(xcffib.Struct):
         self.value = xcffib.List(unpacker, "I", self.length // 4)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
-        buf.write(struct.pack("=I", self.length))
+        buf = io.BytesIO()
         buf.write(self.spec.pack() if hasattr(self.spec, "pack") else ClientIdSpec.synthetic(*self.spec).pack())
+        buf.write(struct.pack("=I", self.length))
         buf.write(xcffib.pack_list(self.value, "I"))
         return buf.getvalue()
     @classmethod
@@ -92,6 +96,7 @@ class ClientIdValue(xcffib.Struct):
         self.value = value
         return self
 class ResourceIdSpec(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -100,7 +105,7 @@ class ResourceIdSpec(xcffib.Struct):
         self.resource, self.type = unpacker.unpack("II")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=II", self.resource, self.type))
         return buf.getvalue()
     fixed_size = 8
@@ -111,6 +116,7 @@ class ResourceIdSpec(xcffib.Struct):
         self.type = type
         return self
 class ResourceSizeSpec(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -120,9 +126,11 @@ class ResourceSizeSpec(xcffib.Struct):
         self.bytes, self.ref_count, self.use_count = unpacker.unpack("III")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
-        buf.write(struct.pack("=III", self.bytes, self.ref_count, self.use_count))
+        buf = io.BytesIO()
         buf.write(self.spec.pack() if hasattr(self.spec, "pack") else ResourceIdSpec.synthetic(*self.spec).pack())
+        buf.write(struct.pack("=I", self.bytes))
+        buf.write(struct.pack("=I", self.ref_count))
+        buf.write(struct.pack("=I", self.use_count))
         return buf.getvalue()
     @classmethod
     def synthetic(cls, spec, bytes, ref_count, use_count):
@@ -133,6 +141,7 @@ class ResourceSizeSpec(xcffib.Struct):
         self.use_count = use_count
         return self
 class ResourceSizeValue(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -144,9 +153,9 @@ class ResourceSizeValue(xcffib.Struct):
         self.cross_references = xcffib.List(unpacker, ResourceSizeSpec, self.num_cross_references)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
-        buf.write(struct.pack("=I", self.num_cross_references))
+        buf = io.BytesIO()
         buf.write(self.size.pack() if hasattr(self.size, "pack") else ResourceSizeSpec.synthetic(*self.size).pack())
+        buf.write(struct.pack("=I", self.num_cross_references))
         buf.write(xcffib.pack_list(self.cross_references, ResourceSizeSpec))
         return buf.getvalue()
     @classmethod
@@ -157,6 +166,7 @@ class ResourceSizeValue(xcffib.Struct):
         self.cross_references = cross_references
         return self
 class QueryVersionReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -167,6 +177,7 @@ class QueryVersionReply(xcffib.Reply):
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 class QueryClientsReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -178,6 +189,7 @@ class QueryClientsReply(xcffib.Reply):
 class QueryClientsCookie(xcffib.Cookie):
     reply_type = QueryClientsReply
 class QueryClientResourcesReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -189,6 +201,7 @@ class QueryClientResourcesReply(xcffib.Reply):
 class QueryClientResourcesCookie(xcffib.Cookie):
     reply_type = QueryClientResourcesReply
 class QueryClientPixmapBytesReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -199,6 +212,7 @@ class QueryClientPixmapBytesReply(xcffib.Reply):
 class QueryClientPixmapBytesCookie(xcffib.Cookie):
     reply_type = QueryClientPixmapBytesReply
 class QueryClientIdsReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -210,6 +224,7 @@ class QueryClientIdsReply(xcffib.Reply):
 class QueryClientIdsCookie(xcffib.Cookie):
     reply_type = QueryClientIdsReply
 class QueryResourceBytesReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -222,28 +237,28 @@ class QueryResourceBytesCookie(xcffib.Cookie):
     reply_type = QueryResourceBytesReply
 class resExtension(xcffib.Extension):
     def QueryVersion(self, client_major, client_minor, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xBB", client_major, client_minor))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
     def QueryClients(self, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(1, buf, QueryClientsCookie, is_checked=is_checked)
     def QueryClientResources(self, xid, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", xid))
         return self.send_request(2, buf, QueryClientResourcesCookie, is_checked=is_checked)
     def QueryClientPixmapBytes(self, xid, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", xid))
         return self.send_request(3, buf, QueryClientPixmapBytesCookie, is_checked=is_checked)
     def QueryClientIds(self, num_specs, specs, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", num_specs))
         buf.write(xcffib.pack_list(specs, ClientIdSpec))
         return self.send_request(4, buf, QueryClientIdsCookie, is_checked=is_checked)
     def QueryResourceBytes(self, client, num_specs, specs, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", client, num_specs))
         buf.write(xcffib.pack_list(specs, ResourceIdSpec))
         return self.send_request(5, buf, QueryResourceBytesCookie, is_checked=is_checked)
