@@ -20,6 +20,7 @@ class State:
     Cycle = 2
     Disabled = 3
 class QueryVersionReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -30,6 +31,7 @@ class QueryVersionReply(xcffib.Reply):
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 class QueryInfoReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -40,6 +42,7 @@ class QueryInfoReply(xcffib.Reply):
 class QueryInfoCookie(xcffib.Cookie):
     reply_type = QueryInfoReply
 class NotifyEvent(xcffib.Event):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -82,49 +85,49 @@ class screensaverExtension(xcffib.Extension):
     def SetAttributes(self, drawable, x, y, width, height, border_width, _class, depth, visual, value_mask, value_list, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIhhHHHBBII", drawable, x, y, width, height, border_width, _class, depth, visual, value_mask))
-        if value_mask & CW.BackPixmap:
+        if value_mask & xproto.CW:
             background_pixmap = value_list.pop(0)
             buf.write(struct.pack("=I", background_pixmap))
-        if value_mask & CW.BackPixel:
+        if value_mask & xproto.CW:
             background_pixel = value_list.pop(0)
             buf.write(struct.pack("=I", background_pixel))
-        if value_mask & CW.BorderPixmap:
+        if value_mask & xproto.CW:
             border_pixmap = value_list.pop(0)
             buf.write(struct.pack("=I", border_pixmap))
-        if value_mask & CW.BorderPixel:
+        if value_mask & xproto.CW:
             border_pixel = value_list.pop(0)
             buf.write(struct.pack("=I", border_pixel))
-        if value_mask & CW.BitGravity:
+        if value_mask & xproto.CW:
             bit_gravity = value_list.pop(0)
             buf.write(struct.pack("=I", bit_gravity))
-        if value_mask & CW.WinGravity:
+        if value_mask & xproto.CW:
             win_gravity = value_list.pop(0)
             buf.write(struct.pack("=I", win_gravity))
-        if value_mask & CW.BackingStore:
+        if value_mask & xproto.CW:
             backing_store = value_list.pop(0)
             buf.write(struct.pack("=I", backing_store))
-        if value_mask & CW.BackingPlanes:
+        if value_mask & xproto.CW:
             backing_planes = value_list.pop(0)
             buf.write(struct.pack("=I", backing_planes))
-        if value_mask & CW.BackingPixel:
+        if value_mask & xproto.CW:
             backing_pixel = value_list.pop(0)
             buf.write(struct.pack("=I", backing_pixel))
-        if value_mask & CW.OverrideRedirect:
+        if value_mask & xproto.CW:
             override_redirect = value_list.pop(0)
             buf.write(struct.pack("=I", override_redirect))
-        if value_mask & CW.SaveUnder:
+        if value_mask & xproto.CW:
             save_under = value_list.pop(0)
             buf.write(struct.pack("=I", save_under))
-        if value_mask & CW.EventMask:
+        if value_mask & xproto.CW:
             event_mask = value_list.pop(0)
             buf.write(struct.pack("=I", event_mask))
-        if value_mask & CW.DontPropagate:
+        if value_mask & xproto.CW:
             do_not_propogate_mask = value_list.pop(0)
             buf.write(struct.pack("=I", do_not_propogate_mask))
-        if value_mask & CW.Colormap:
+        if value_mask & xproto.CW:
             colormap = value_list.pop(0)
             buf.write(struct.pack("=I", colormap))
-        if value_mask & CW.Cursor:
+        if value_mask & xproto.CW:
             cursor = value_list.pop(0)
             buf.write(struct.pack("=I", cursor))
         return self.send_request(3, buf, is_checked=is_checked)
